[tor-commits] [goptlib/master] Update setup loop examples.

2014-01-12 Thread dcf
commit 5a089f3f33bab6b066baad3911dc6e0d8231ce1c
Author: David Fifield 
Date:   Sun Jan 12 23:29:00 2014 -0800

Update setup loop examples.
---
 pt.go |   34 ++
 1 file changed, 22 insertions(+), 12 deletions(-)

diff --git a/pt.go b/pt.go
index 024eec9..181097e 100644
--- a/pt.go
+++ b/pt.go
@@ -40,13 +40,18 @@
 // os.Exit(1)
 // }
 // for _, methodName := range ptInfo.MethodNames {
-// ln, err := pt.ListenSocks("tcp", "127.0.0.1:0")
-// if err != nil {
-// pt.CmethodError(methodName, err.Error())
-// continue
+// switch methodName {
+// case "foo":
+// ln, err := pt.ListenSocks("tcp", "127.0.0.1:0")
+// if err != nil {
+// pt.CmethodError(methodName, err.Error())
+// break
+// }
+// go acceptLoop(ln)
+// pt.Cmethod(methodName, ln.Version(), ln.Addr())
+// default:
+// pt.CmethodError(methodName, "no such method")
 // }
-// go acceptLoop(ln)
-// pt.Cmethod(methodName, ln.Version(), ln.Addr())
 // }
 // pt.CmethodsDone()
 // }
@@ -86,13 +91,18 @@
 // os.Exit(1)
 // }
 // for _, bindaddr := range ptInfo.Bindaddrs {
-// ln, err := net.ListenTCP("tcp", bindaddr.Addr)
-// if err != nil {
-// pt.SmethodError(bindaddr.MethodName, 
err.Error())
-// continue
+// switch bindaddr.MethodName {
+// case "foo":
+// ln, err := net.ListenTCP("tcp", bindaddr.Addr)
+// if err != nil {
+// pt.SmethodError(bindaddr.MethodName, 
err.Error())
+// break
+// }
+// go acceptLoop(ln)
+// pt.Smethod(bindaddr.MethodName, ln.Addr())
+// default:
+// pt.SmethodError(bindaddr.MethodName, "no such 
method")
 // }
-// go acceptLoop(ln)
-// pt.Smethod(bindaddr.MethodName, ln.Addr())
 // }
 // pt.SmethodsDone()
 // }

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [websocket/master] Use new goptlib ServerSetup and ClientSetup.

2014-01-12 Thread dcf
commit 0ea3a5f82ea4dd846d75b17860633504ba110c04
Author: David Fifield 
Date:   Sun Jan 12 23:01:47 2014 -0800

Use new goptlib ServerSetup and ClientSetup.
---
 websocket-client/websocket-client.go |   30 +++---
 websocket-server/websocket-server.go |   19 ---
 2 files changed, 27 insertions(+), 22 deletions(-)

diff --git a/websocket-client/websocket-client.go 
b/websocket-client/websocket-client.go
index 228cb1c..fe38c9d 100644
--- a/websocket-client/websocket-client.go
+++ b/websocket-client/websocket-client.go
@@ -187,13 +187,12 @@ func startListener(addrStr string) (*pt.SocksListener, 
error) {
 
 func main() {
var logFilename string
-   var socksAddrStrs = []string{"127.0.0.1:0"}
-   var socksArg string
+   var socksAddrStr string
var err error
 
flag.Usage = usage
flag.StringVar(&logFilename, "log", "", "log file to write to")
-   flag.StringVar(&socksArg, "socks", "", "address on which to listen for 
SOCKS connections")
+   flag.StringVar(&socksAddrStr, "socks", "127.0.0.1:0", "address on which 
to listen for SOCKS connections")
flag.Parse()
 
if logFilename != "" {
@@ -205,10 +204,6 @@ func main() {
logFile = f
}
 
-   if socksArg != "" {
-   socksAddrStrs = []string{socksArg}
-   }
-
log("starting")
ptInfo, err = pt.ClientSetup([]string{ptMethodName})
if err != nil {
@@ -217,15 +212,20 @@ func main() {
}
 
listeners := make([]net.Listener, 0)
-   for _, socksAddrStr := range socksAddrStrs {
-   ln, err := startListener(socksAddrStr)
-   if err != nil {
-   pt.CmethodError(ptMethodName, err.Error())
-   continue
+   for _, methodName := range ptInfo.MethodNames {
+   switch methodName {
+   case ptMethodName:
+   ln, err := startListener(socksAddrStr)
+   if err != nil {
+   pt.CmethodError(ptMethodName, err.Error())
+   break
+   }
+   pt.Cmethod(ptMethodName, ln.Version(), ln.Addr())
+   log("listening on %s", ln.Addr().String())
+   listeners = append(listeners, ln)
+   default:
+   pt.CmethodError(methodName, "no such method")
}
-   pt.Cmethod(ptMethodName, ln.Version(), ln.Addr())
-   log("listening on %s", ln.Addr().String())
-   listeners = append(listeners, ln)
}
pt.CmethodsDone()
 
diff --git a/websocket-server/websocket-server.go 
b/websocket-server/websocket-server.go
index 64ae7b4..4120df8 100644
--- a/websocket-server/websocket-server.go
+++ b/websocket-server/websocket-server.go
@@ -243,14 +243,19 @@ func main() {
bindaddr.Addr.Port = port
}
 
-   ln, err := startListener(bindaddr.Addr)
-   if err != nil {
-   pt.SmethodError(bindaddr.MethodName, err.Error())
-   continue
+   switch bindaddr.MethodName {
+   case ptMethodName:
+   ln, err := startListener(bindaddr.Addr)
+   if err != nil {
+   pt.SmethodError(bindaddr.MethodName, 
err.Error())
+   break
+   }
+   pt.Smethod(bindaddr.MethodName, ln.Addr())
+   log("listening on %s", ln.Addr().String())
+   listeners = append(listeners, ln)
+   default:
+   pt.SmethodError(bindaddr.MethodName, "no such method")
}
-   pt.Smethod(bindaddr.MethodName, ln.Addr())
-   log("listening on %s", ln.Addr().String())
-   listeners = append(listeners, ln)
}
pt.SmethodsDone()
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [goptlib/master] Use the argument to ClientSetup only when the "*" list is requested.

2014-01-12 Thread dcf
commit 5db12aacc1d56a713a1701a192f987dfccec7363
Author: David Fifield 
Date:   Sun Jan 12 22:38:21 2014 -0800

Use the argument to ClientSetup only when the "*" list is requested.

Formerly the list always served as an additional filter of methods
that we support. Now, ClientSetup always returns all the method names
requested by Tor, unless "*" is requested, in which case the given
method name list is returned.

This change is to enable the case where for "*" you want to return
something other than the full list of transports you support.

https://lists.torproject.org/pipermail/tor-dev/2013-December/005966.html
---
 examples/dummy-client/dummy-client.go |   19 ---
 pt.go |   25 +
 pt_test.go|   22 --
 3 files changed, 37 insertions(+), 29 deletions(-)

diff --git a/examples/dummy-client/dummy-client.go 
b/examples/dummy-client/dummy-client.go
index a0fa488..64f1ec1 100644
--- a/examples/dummy-client/dummy-client.go
+++ b/examples/dummy-client/dummy-client.go
@@ -90,14 +90,19 @@ func main() {
 
listeners := make([]net.Listener, 0)
for _, methodName := range ptInfo.MethodNames {
-   ln, err := pt.ListenSocks("tcp", "127.0.0.1:0")
-   if err != nil {
-   pt.CmethodError(methodName, err.Error())
-   continue
+   switch methodName {
+   case "dummy":
+   ln, err := pt.ListenSocks("tcp", "127.0.0.1:0")
+   if err != nil {
+   pt.CmethodError(methodName, err.Error())
+   break
+   }
+   go acceptLoop(ln)
+   pt.Cmethod(methodName, ln.Version(), ln.Addr())
+   listeners = append(listeners, ln)
+   default:
+   pt.CmethodError(methodName, "no such method")
}
-   go acceptLoop(ln)
-   pt.Cmethod(methodName, ln.Version(), ln.Addr())
-   listeners = append(listeners, ln)
}
pt.CmethodsDone()
 
diff --git a/pt_test.go b/pt_test.go
index a2abc1f..7e74f2b 100644
--- a/pt_test.go
+++ b/pt_test.go
@@ -118,7 +118,7 @@ func tcpAddrsEqual(a, b *net.TCPAddr) bool {
 func TestGetClientTransports(t *testing.T) {
tests := [...]struct {
ptServerClientTransports string
-   methodNames  []string
+   star []string
expected []string
}{
{
@@ -147,21 +147,31 @@ func TestGetClientTransports(t *testing.T) {
[]string{"alpha"},
   

[tor-commits] [goptlib/master] Resolve some "go vet" problems.

2014-01-12 Thread dcf
commit 356518d1bf136dd8e41f4863606e8c414e551136
Author: David Fifield 
Date:   Sun Jan 12 21:40:28 2014 -0800

Resolve some "go vet" problems.
---
 args_test.go  |   20 
 pt_test.go|2 +-
 socks_test.go |6 +++---
 3 files changed, 16 insertions(+), 12 deletions(-)

diff --git a/args_test.go b/args_test.go
index d62968c..daf967e 100644
--- a/args_test.go
+++ b/args_test.go
@@ -67,20 +67,24 @@ func TestArgsGet(t *testing.T) {
 
 func TestArgsAdd(t *testing.T) {
args := make(Args)
-   if !argsEqual(args, Args{}) {
-   t.Error()
+   expected := Args{}
+   if !argsEqual(args, expected) {
+   t.Fatalf("%q != %q", args, expected)
}
args.Add("k1", "v1")
-   if !argsEqual(args, Args{"k1": []string{"v1"}}) {
-   t.Error()
+   expected = Args{"k1": []string{"v1"}}
+   if !argsEqual(args, expected) {
+   t.Fatalf("%q != %q", args, expected)
}
args.Add("k2", "v2")
-   if !argsEqual(args, Args{"k1": []string{"v1"}, "k2": []string{"v2"}}) {
-   t.Error()
+   expected = Args{"k1": []string{"v1"}, "k2": []string{"v2"}}
+   if !argsEqual(args, expected) {
+   t.Fatalf("%q != %q", args, expected)
}
args.Add("k1", "v3")
-   if !argsEqual(args, Args{"k1": []string{"v1", "v3"}, "k2": 
[]string{"v2"}}) {
-   t.Error()
+   expected = Args{"k1": []string{"v1", "v3"}, "k2": []string{"v2"}}
+   if !argsEqual(args, expected) {
+   t.Fatalf("%q != %q", args, expected)
}
 }
 
diff --git a/pt_test.go b/pt_test.go
index a6b7a02..f7e9156 100644
--- a/pt_test.go
+++ b/pt_test.go
@@ -643,7 +643,7 @@ func testExtOrPortSetupIndividual(t *testing.T, addr, 
methodName string) {
// fake an OKAY response.
err = extOrPortSendCommand(&buf.ReadBuf, extOrCmdOkay, []byte{})
if err != nil {
-   t.Fatal()
+   t.Fatal(err)
}
err = extOrPortSetup(&buf, addr, methodName)
if err != nil {
diff --git a/socks_test.go b/socks_test.go
index 6cfa967..7f97e9a 100644
--- a/socks_test.go
+++ b/socks_test.go
@@ -85,7 +85,7 @@ func TestReadSocks4aConnect(t *testing.T) {
}
addr, err := net.ResolveTCPAddr("tcp", req.Target)
if err != nil {
-   t.Error("%q → target %q: cannot resolve: %s", 
test.input,
+   t.Errorf("%q → target %q: cannot resolve: %s", 
test.input,
req.Target, err)
}
if !tcpAddrsEqual(addr, &test.addr) {
@@ -144,7 +144,7 @@ func TestSendSocks4aResponse(t *testing.T) {
var buf bytes.Buffer
err := sendSocks4aResponse(&buf, test.code, &test.addr)
if err != nil {
-   t.Errorf("0x%02x %s unexpectedly returned an error: 
%s", test.code, test.addr, err)
+   t.Errorf("0x%02x %s unexpectedly returned an error: 
%s", test.code, &test.addr, err)
}
p := make([]byte, 1024)
n, err := buf.Read(p)
@@ -154,7 +154,7 @@ func TestSendSocks4aResponse(t *testing.T) {
output := p[:n]
if !bytes.Equal(output, test.expected) {
t.Errorf("0x%02x %s → %v (expected %v)",
-   test.code, test.addr, output, test.expected)
+   test.code, &test.addr, output, test.expected)
}
}
 }



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [goptlib/master] Remove unreachable code "go vet" complained about.

2014-01-12 Thread dcf
commit 3f18f71ed305b255934114951950525f89fbfcb0
Author: David Fifield 
Date:   Sun Jan 12 21:26:43 2014 -0800

Remove unreachable code "go vet" complained about.
---
 examples/dummy-client/dummy-client.go |1 -
 examples/dummy-server/dummy-server.go |1 -
 2 files changed, 2 deletions(-)

diff --git a/examples/dummy-client/dummy-client.go 
b/examples/dummy-client/dummy-client.go
index e1cede5..a0fa488 100644
--- a/examples/dummy-client/dummy-client.go
+++ b/examples/dummy-client/dummy-client.go
@@ -78,7 +78,6 @@ func acceptLoop(ln *pt.SocksListener) error {
}
go handler(conn)
}
-   return nil
 }
 
 func main() {
diff --git a/examples/dummy-server/dummy-server.go 
b/examples/dummy-server/dummy-server.go
index 94b7bb6..7e8ad96 100644
--- a/examples/dummy-server/dummy-server.go
+++ b/examples/dummy-server/dummy-server.go
@@ -75,7 +75,6 @@ func acceptLoop(ln net.Listener) error {
}
go handler(conn)
}
-   return nil
 }
 
 func main() {



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [goptlib/master] Use the argument to ServerSetup only when the "*" list is requested.

2014-01-12 Thread dcf
commit f9316c52f21767bb5b0cd534d01fdf4efb4716f7
Author: David Fifield 
Date:   Sun Jan 12 21:58:35 2014 -0800

Use the argument to ServerSetup only when the "*" list is requested.

Formerly the list always served as an additional filter of methods that
we support. Now, ServerSetup always returns all the method names
requested by Tor, unless "*" is requested, in which case the given
method name list is returned.

This change is to enable the case where the list of method names is not
known in advance.

https://lists.torproject.org/pipermail/tor-dev/2013-December/005966.html
---
 examples/dummy-server/dummy-server.go |   19 ---
 pt.go |   29 +++--
 pt_test.go|   27 +++
 3 files changed, 46 insertions(+), 29 deletions(-)

diff --git a/examples/dummy-server/dummy-server.go 
b/examples/dummy-server/dummy-server.go
index 7e8ad96..ea91be9 100644
--- a/examples/dummy-server/dummy-server.go
+++ b/examples/dummy-server/dummy-server.go
@@ -87,14 +87,19 @@ func main() {
 
listeners := make([]net.Listener, 0)
for _, bindaddr := range ptInfo.Bindaddrs {
-   ln, err := net.ListenTCP("tcp", bindaddr.Addr)
-   if err != nil {
-   pt.SmethodError(bindaddr.MethodName, err.Error())
-   continue
+   switch bindaddr.MethodName {
+   case "dummy":
+   ln, err := net.ListenTCP("tcp", bindaddr.Addr)
+   if err != nil {
+   pt.SmethodError(bindaddr.MethodName, 
err.Error())
+   break
+   }
+   go acceptLoop(ln)
+   pt.Smethod(bindaddr.MethodName, ln.Addr())
+   listeners = append(listeners, ln)
+   default:
+   pt.SmethodError(bindaddr.MethodName, "no such method")
}
-   go acceptLoop(ln)
-   pt.Smethod(bindaddr.MethodName, ln.Addr())
-   listeners = append(listeners, ln)
}
pt.SmethodsDone()
 
diff --git a/pt_test.go b/pt_test.go
index f7e9156..a2abc1f 100644
--- 

[tor-commits] [translation/tsum] Update translations for tsum

2014-01-12 Thread translation
commit bd24432527f6afa51e9961654cdad5cfb7dba1e2
Author: Translation commit bot 
Date:   Mon Jan 13 05:15:09 2014 +

Update translations for tsum
---
 ta/short-user-manual_ta_noimg.xhtml |  132 +++
 1 file changed, 132 insertions(+)

diff --git a/ta/short-user-manual_ta_noimg.xhtml 
b/ta/short-user-manual_ta_noimg.xhtml
new file mode 100644
index 000..2979d41
--- /dev/null
+++ b/ta/short-user-manual_ta_noimg.xhtml
@@ -0,0 +1,132 @@
+http://www.w3.org/1999/xhtml";>
+  
+
+
+  
+  
+குறுகிய பயனர் 
கையேடு
+This user manual contains information about how to download Tor, how to 
use it, and what to do if Tor is unable to connect to the network. If you can't 
find the answer to your question in this document, email 
h...@rt.torproject.org.
+Please note that we are providing support on a voluntary basis, and we 
get a lot of emails every single day. There is no need to worry if we don't get 
back to you straight away.
+எப்படி Tor 
வேலைசெய்கிறது
+Tor is a network of virtual tunnels that allows you to improve your 
privacy and security on the Internet. Tor works by sending your traffic through 
three random servers (also known as relays) in the Tor network, before 
the traffic is sent out onto the public Internet.
+The image above illustrates a user browsing to different websites over 
Tor. The green monitors represent relays in the Tor network, while the three 
keys represent the layers of encryption between the user and each relay.
+Tor will anonymize the origin of your traffic, and it will encrypt 
everything between you and the Tor network. Tor will also encrypt your traffic 
inside the Tor network, but it cannot encrypt your traffic between the Tor 
network and its final destination.
+If you are communicating sensitive information, for example when 
logging on to a website with a username and password, make sure that you are 
using HTTPS (e.g. https://torproject.org/, not 
http://torproject.org/).
+Tor-ஐ எப்படி 
பதிவிறக்கலாம்
+The bundle we recommend to most users is the https://www.torproject.org/projects/torbrowser.html";>Tor Browser 
Bundle. This bundle contains a browser preconfigured to safely browse the 
Internet through Tor, and requires no installation. You download the bundle, 
extract the archive, and start Tor.
+There are two different ways to get hold of the Tor software. You can 
either browse to the https://www.torproject.org/";>Tor Project 
website and download it there, or you can use GetTor, the email 
autoresponder.
+மின்னஞ்சல் 
வழியாக Tor-ஐ பெறவது எப்படி
+To receive the English Tor Browser Bundle for Windows, send an email to 
get...@torproject.org with windows in the body of the message. 
You can leave the subject blank.
+You can also request the Tor Browser Bundle for Mac OS X (write 
macos-i386), and Linux (write linux-i386 for 
32-bit systems or linux-x86_64 for 64-bit systems).
+If you want a translated version of Tor, write help 
instead. You will then receive an email with instructions and a list of 
available languages.
+Note: The Tor Browser Bundles for Linux and Mac OS X 
are rather large, and you will not be able to receive any of these bundles with 
a Gmail, Hotmail or Yahoo account. If you cannot receive the bundle you want, 
send an email to h...@rt.torproject.org and we will give you a list of website 
mirrors to use.
+Tor for smartphones
+You can get Tor on your Android device by installing the package named 
Orbot. For information about how to download and install Orbot, please 
see the https://www.torproject.org/docs/android.html.en";>Tor Project 
website.
+We also have experimental packages for https://www.torproject.org/docs/N900.html.en";>Nokia Maemo/N900 and http://sid77.slackware.it/iphone/";>Apple iOS.
+How to verify that 
you have the right version
+Before running the Tor Browser Bundle, you should make sure that you 
have the right version.
+The software you receive is accompanied by a file with the same name as 
the bundle and the extension .asc. This .asc file is a GPG 
signature, and will allow you to verify the file you've downloaded is exactly 
the one that we intended you to get.
+Before you can verify the signature, you will have to download and 
install GnuPG:
+Windows: http://gpg4win.org/download.html";>http://gpg4win.org/download.htmlMac
 OS X: http://macgpg.sourceforge.net/";>http://macgpg.sourceforge.net/Linux:
 Most Linux distributions come with GnuPG preinstalled.
+Please note that you may need to edit the paths and the commands used 
below to get it to work on your system.
+Erinn Clark signs the Tor Browser Bundles with key 0x63FEE659. To 
import Erinn's key, run:
+
+  gpg --keyserver hkp://keys.gnupg.net  --recv-keys 0x6

[tor-commits] [translation/tails-misc] Update translations for tails-misc

2014-01-12 Thread translation
commit e3e756e4ec0e4ef5aa50fa59a7ab2af2f9f941c1
Author: Translation commit bot 
Date:   Sun Jan 12 22:46:14 2014 +

Update translations for tails-misc
---
 pl.po |   12 ++--
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/pl.po b/pl.po
index db3d5b2..c62e697 100644
--- a/pl.po
+++ b/pl.po
@@ -5,14 +5,14 @@
 # Translators:
 # hoek , 2014
 # phla47 , 2013
-# sebx, 2013
+# sebx, 2013-2014
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2014-01-10 12:23+0100\n"
-"PO-Revision-Date: 2014-01-11 08:57+\n"
-"Last-Translator: runasand \n"
+"PO-Revision-Date: 2014-01-12 22:28+\n"
+"Last-Translator: sebx\n"
 "Language-Team: Polish 
(http://www.transifex.com/projects/p/torproject/language/pl/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -152,9 +152,9 @@ msgstr "Czy ufasz tym kluczom?"
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:551
 msgid "The following selected key is not fully trusted:"
 msgid_plural "The following selected keys are not fully trusted:"
-msgstr[0] "Poniżej wybrane klucze nie są do końca zaufane:"
-msgstr[1] "Poniżej wybrane klucze nie są do końca zaufane:"
-msgstr[2] "Poniżej wybrane klucze nie są do końca zaufane:"
+msgstr[0] "Wybrany klucz nie jest do końca zaufany:"
+msgstr[1] "Wybrany klucz nie jest do końca zaufany:"
+msgstr[2] "Wybrane klucze nie są do końca zaufane:"
 
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:569
 msgid "Do you trust this key enough to use it anyway?"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-misc_completed] Update translations for tails-misc_completed

2014-01-12 Thread translation
commit 47764d3c56b4f95c32001740ff80e73b7d421aab
Author: Translation commit bot 
Date:   Sun Jan 12 22:46:19 2014 +

Update translations for tails-misc_completed
---
 pl.po |   12 ++--
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/pl.po b/pl.po
index db3d5b2..c62e697 100644
--- a/pl.po
+++ b/pl.po
@@ -5,14 +5,14 @@
 # Translators:
 # hoek , 2014
 # phla47 , 2013
-# sebx, 2013
+# sebx, 2013-2014
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2014-01-10 12:23+0100\n"
-"PO-Revision-Date: 2014-01-11 08:57+\n"
-"Last-Translator: runasand \n"
+"PO-Revision-Date: 2014-01-12 22:28+\n"
+"Last-Translator: sebx\n"
 "Language-Team: Polish 
(http://www.transifex.com/projects/p/torproject/language/pl/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -152,9 +152,9 @@ msgstr "Czy ufasz tym kluczom?"
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:551
 msgid "The following selected key is not fully trusted:"
 msgid_plural "The following selected keys are not fully trusted:"
-msgstr[0] "Poniżej wybrane klucze nie są do końca zaufane:"
-msgstr[1] "Poniżej wybrane klucze nie są do końca zaufane:"
-msgstr[2] "Poniżej wybrane klucze nie są do końca zaufane:"
+msgstr[0] "Wybrany klucz nie jest do końca zaufany:"
+msgstr[1] "Wybrany klucz nie jest do końca zaufany:"
+msgstr[2] "Wybrane klucze nie są do końca zaufane:"
 
 #: config/chroot_local-includes/usr/local/bin/gpgApplet:569
 msgid "Do you trust this key enough to use it anyway?"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] r26532: {website} Renaming JTor to Orchid JTor has been renamed to Orchid. Als (website/trunk/getinvolved/en)

2014-01-12 Thread Damian Johnson
Author: atagar
Date: 2014-01-12 20:55:06 + (Sun, 12 Jan 2014)
New Revision: 26532

Modified:
   website/trunk/getinvolved/en/volunteer.wml
Log:
Renaming JTor to Orchid

JTor has been renamed to Orchid. Also dropping the note saying that it has been
inactive...

https://trac.torproject.org/10618



Modified: website/trunk/getinvolved/en/volunteer.wml
===
--- website/trunk/getinvolved/en/volunteer.wml  2014-01-12 17:55:38 UTC (rev 
26531)
+++ website/trunk/getinvolved/en/volunteer.wml  2014-01-12 20:55:06 UTC (rev 
26532)
@@ -132,7 +132,7 @@
   
 
   
-*JTor
+*Orchid
 Core
 Java
 Moderate
@@ -430,16 +430,14 @@
 Make Chutney Do More, More Reliably
 
 
-
-https://github.com/brl/JTor/wiki";>JTor (https://gitweb.torproject.org/jtor.git";>code, https://github.com/brl/JTor/issues";>bug
+
+https://github.com/subgraph/Orchid";>Orchid (https://github.com/subgraph/Orchid";>code, https://github.com/subgraph/Orchid/issues";>bug
 tracker)
 
 
-Java implementation of Tor and successor to http://onioncoffee.sourceforge.net/";>OnionCoffee. This project
-isn't yet complete, and has been inactive since Fall 2010.
+Java implementation of Tor and successor to http://onioncoffee.sourceforge.net/";>OnionCoffee.
 
 
 

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-iuk] Update translations for tails-iuk

2014-01-12 Thread translation
commit 76149b1e5bb7bc3df136d60075d0666a5826352d
Author: Translation commit bot 
Date:   Sun Jan 12 18:46:32 2014 +

Update translations for tails-iuk
---
 pl.po |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/pl.po b/pl.po
index 31d3c73..d86dbfb 100644
--- a/pl.po
+++ b/pl.po
@@ -4,14 +4,14 @@
 # 
 # Translators:
 # hoek , 2014
-# sebx, 2013
+# sebx, 2013-2014
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: Tails developers \n"
 "POT-Creation-Date: 2014-01-07 20:17+0100\n"
-"PO-Revision-Date: 2014-01-10 12:10+\n"
-"Last-Translator: hoek \n"
+"PO-Revision-Date: 2014-01-12 18:40+\n"
+"Last-Translator: sebx\n"
 "Language-Team: Polish 
(http://www.transifex.com/projects/p/torproject/language/pl/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -58,7 +58,7 @@ msgstr "Ta wersja Tails jest nieaktualna i może mieć 
problemy z bezpieczeństw
 msgid ""
 "The available incremental upgrade requires %{space_needed}s of free space on"
 " Tails system partition,  but only %{free_space}s is available."
-msgstr "Następująca aktualizacja wymaga %{space_needed}s wolnego miejsca na 
partycji systemu Tails. Obecnie jest tylko %{free_space}s dostępnego miejsca."
+msgstr "Następująca przyrostkowa aktualizacja wymaga %{space_needed}s 
wolnego miejsca na partycji systemu Tails. Obecnie jest tylko %{free_space}s 
dostępnego miejsca."
 
 #: ../lib/Tails/IUK/Frontend.pm:279
 #, perl-brace-format

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-iuk_completed] Update translations for tails-iuk_completed

2014-01-12 Thread translation
commit 03b2b4f7111d3b4898f4bf604b82ccfc96f9b89b
Author: Translation commit bot 
Date:   Sun Jan 12 18:46:35 2014 +

Update translations for tails-iuk_completed
---
 pl.po |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/pl.po b/pl.po
index 31d3c73..d86dbfb 100644
--- a/pl.po
+++ b/pl.po
@@ -4,14 +4,14 @@
 # 
 # Translators:
 # hoek , 2014
-# sebx, 2013
+# sebx, 2013-2014
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: Tails developers \n"
 "POT-Creation-Date: 2014-01-07 20:17+0100\n"
-"PO-Revision-Date: 2014-01-10 12:10+\n"
-"Last-Translator: hoek \n"
+"PO-Revision-Date: 2014-01-12 18:40+\n"
+"Last-Translator: sebx\n"
 "Language-Team: Polish 
(http://www.transifex.com/projects/p/torproject/language/pl/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -58,7 +58,7 @@ msgstr "Ta wersja Tails jest nieaktualna i może mieć 
problemy z bezpieczeństw
 msgid ""
 "The available incremental upgrade requires %{space_needed}s of free space on"
 " Tails system partition,  but only %{free_space}s is available."
-msgstr "Następująca aktualizacja wymaga %{space_needed}s wolnego miejsca na 
partycji systemu Tails. Obecnie jest tylko %{free_space}s dostępnego miejsca."
+msgstr "Następująca przyrostkowa aktualizacja wymaga %{space_needed}s 
wolnego miejsca na partycji systemu Tails. Obecnie jest tylko %{free_space}s 
dostępnego miejsca."
 
 #: ../lib/Tails/IUK/Frontend.pm:279
 #, perl-brace-format

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/liveusb-creator_completed] Update translations for liveusb-creator_completed

2014-01-12 Thread translation
commit 3a0e074e16ac22e0d832683f2e70b7370d1e05c8
Author: Translation commit bot 
Date:   Sun Jan 12 18:46:03 2014 +

Update translations for liveusb-creator_completed
---
 pl/pl.po |  132 +++---
 1 file changed, 66 insertions(+), 66 deletions(-)

diff --git a/pl/pl.po b/pl/pl.po
index 106bef3..a52450a 100644
--- a/pl/pl.po
+++ b/pl/pl.po
@@ -8,13 +8,13 @@
 # Quaithe , 2013
 # Quaithe , 2013
 # Piotr Drąg , 2008
-# sebx, 2013
+# sebx, 2013-2014
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2013-11-12 13:29+0100\n"
-"PO-Revision-Date: 2013-11-15 00:20+\n"
+"POT-Creation-Date: 2014-01-10 11:27+0100\n"
+"PO-Revision-Date: 2014-01-12 18:42+\n"
 "Last-Translator: sebx\n"
 "Language-Team: Polish 
(http://www.transifex.com/projects/p/torproject/language/pl/)\n"
 "MIME-Version: 1.0\n"
@@ -25,25 +25,25 @@ msgstr ""
 
 #: ../liveusb/dialog.py:159 ../liveusb/launcher_ui.py:158
 #, python-format
-msgid "%(distribution)s installer"
-msgstr "%(distribution)s instalator"
+msgid "%(distribution)s Installer"
+msgstr "%(distribution)s Instalator"
 
-#: ../liveusb/gui.py:807
+#: ../liveusb/gui.py:808
 #, python-format
 msgid "%(filename)s selected"
 msgstr "Wybrano %(filename)s"
 
-#: ../liveusb/gui.py:437
+#: ../liveusb/gui.py:439
 #, python-format
 msgid "%(size)s %(label)s"
 msgstr "%(size)s %(label)s"
 
-#: ../liveusb/gui.py:443
+#: ../liveusb/gui.py:445
 #, python-format
 msgid "%(vendor)s %(model)s (%(details)s) - %(device)s"
 msgstr "%(vendor)s %(model)s (%(details)s) - %(device)s"
 
-#: ../liveusb/creator.py:1023
+#: ../liveusb/creator.py:1020
 #, python-format
 msgid "%s already bootable"
 msgstr "%s jest już startowa"
@@ -100,16 +100,16 @@ msgid ""
 "persist after a reboot."
 msgstr "Poprzez alokację dodatkowej przestrzeni na dysku USB dla obszaru 
trwałych danych, można zapisywać dane i dokonywać trwałych zmian w 
działającym systemie.\nBez niego, nie będzie można zapisywać danych, 
które przetrwają restart."
 
-#: ../liveusb/creator.py:1125 ../liveusb/creator.py:1388
+#: ../liveusb/creator.py:1122 ../liveusb/creator.py:1385
 #, python-format
 msgid "Calculating the SHA1 of %s"
 msgstr "Obliczanie sumy kontrolnej SHA1 pliku %s"
 
-#: ../liveusb/creator.py:1336
+#: ../liveusb/creator.py:1333
 msgid "Cannot find"
 msgstr "Nie znaleziono"
 
-#: ../liveusb/creator.py:545
+#: ../liveusb/creator.py:542
 #, python-format
 msgid "Cannot find device %s"
 msgstr "Nie można odnaleźć urządzenia %s"
@@ -133,7 +133,7 @@ msgstr "Klonuj\ni\nAktualizuj"
 msgid "Creating %sMB persistent overlay"
 msgstr "Tworzenie %sMB warstw trwałych"
 
-#: ../liveusb/gui.py:565
+#: ../liveusb/gui.py:567
 msgid ""
 "Device is not yet mounted, so we cannot determine the amount of free space."
 msgstr "Urządzenie nie jest jeszcze zamontowane, więc nie da się określić 
ilości wolnego miejsca."
@@ -143,11 +143,11 @@ msgstr "Urządzenie nie jest jeszcze zamontowane, więc 
nie da się określić i
 msgid "Download %(distribution)s"
 msgstr "Pobierz %(distribution)s"
 
-#: ../liveusb/gui.py:781
+#: ../liveusb/gui.py:782
 msgid "Download complete!"
 msgstr "Pobieranie ukończone."
 
-#: ../liveusb/gui.py:785
+#: ../liveusb/gui.py:786
 msgid "Download failed: "
 msgstr "Pobieranie nie powiodło się: "
 
@@ -156,16 +156,16 @@ msgstr "Pobieranie nie powiodło się: "
 msgid "Downloading %s..."
 msgstr "Pobieranie %s..."
 
-#: ../liveusb/creator.py:1121
+#: ../liveusb/creator.py:1118
 msgid "Drive is a loopback, skipping MBR reset"
 msgstr "Napęd jest urządzeniem loopback, pomijanie przywracania MBR"
 
-#: ../liveusb/creator.py:816
+#: ../liveusb/creator.py:813
 #, python-format
 msgid "Entering unmount_device for '%(device)s'"
 msgstr "Odmontowywanie urzadzenia '%(device)s'"
 
-#: ../liveusb/creator.py:1201
+#: ../liveusb/creator.py:1198
 msgid "Error probing device"
 msgstr "Błąd podczas wykrywania urządzenia"
 
@@ -185,7 +185,7 @@ msgstr "Błąd: suma kontrolna SHA1 obrazu Live CD jest 
nieprawidłowa. Można u
 msgid "Extracting live image to the target device..."
 msgstr "Wypakowywanie obrazu na wybrane urządzenie..."
 
-#: ../liveusb/creator.py:1066
+#: ../liveusb/creator.py:1063
 #, python-format
 msgid "Formatting %(device)s as FAT32"
 msgstr "Formatowanie %(device)s jako FAT32"
@@ -208,7 +208,7 @@ msgstr "Jeśli nie wybierzesz istniejącego obrazu ISO 
Live, wybrane wydanie zos
 msgid "Install Tails"
 msgstr "Zainstaluj Tails"
 
-#: ../liveusb/gui.py:628
+#: ../liveusb/gui.py:630
 msgid "Installation complete!"
 msgstr "Zakończono instalację!"
 
@@ -217,11 +217,11 @@ msgstr "Zakończono instalację!"
 msgid "Installation complete! (%s)"
 msgstr "Zakończono instalację! (%s)"
 
-#: ../liveusb/gui.py:629
+#: ../liveusb/gui.py:631
 msgid "Installation was completed. Press OK to close this program."
 msgstr "Zakończono instalację.  Nacisnij OK aby zamknąć ten program."
 
-#: ../liv

[tor-commits] [translation/liveusb-creator] Update translations for liveusb-creator

2014-01-12 Thread translation
commit 327b4cf4748ea09e65693e07fff17536b0c1fe69
Author: Translation commit bot 
Date:   Sun Jan 12 18:45:59 2014 +

Update translations for liveusb-creator
---
 pl/pl.po |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/pl/pl.po b/pl/pl.po
index 80472c8..a52450a 100644
--- a/pl/pl.po
+++ b/pl/pl.po
@@ -8,14 +8,14 @@
 # Quaithe , 2013
 # Quaithe , 2013
 # Piotr Drąg , 2008
-# sebx, 2013
+# sebx, 2013-2014
 msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2014-01-10 11:27+0100\n"
-"PO-Revision-Date: 2014-01-11 09:25+\n"
-"Last-Translator: runasand \n"
+"PO-Revision-Date: 2014-01-12 18:42+\n"
+"Last-Translator: sebx\n"
 "Language-Team: Polish 
(http://www.transifex.com/projects/p/torproject/language/pl/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -26,7 +26,7 @@ msgstr ""
 #: ../liveusb/dialog.py:159 ../liveusb/launcher_ui.py:158
 #, python-format
 msgid "%(distribution)s Installer"
-msgstr ""
+msgstr "%(distribution)s Instalator"
 
 #: ../liveusb/gui.py:808
 #, python-format

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] r26531: {website} add 2 new mirrors. (website/trunk/include)

2014-01-12 Thread Andrew Lewman
Author: phobos
Date: 2014-01-12 17:55:38 + (Sun, 12 Jan 2014)
New Revision: 26531

Modified:
   website/trunk/include/tor-mirrors.csv
Log:
add 2 new mirrors.


Modified: website/trunk/include/tor-mirrors.csv
===
--- website/trunk/include/tor-mirrors.csv   2014-01-11 18:38:17 UTC (rev 
26530)
+++ website/trunk/include/tor-mirrors.csv   2014-01-12 17:55:38 UTC (rev 
26531)
@@ -75,3 +75,5 @@
 t...@les.net, t...@les.net, CA, Canada, CA, TRUE, FALSE, NO, 
http://tor.les.net/, , , , http://tor.les.net/dist, , , , Wed Jan  8 16:41:17 
2014
 Tor Fan, PW, DE, Germany, DE, TRUE, TRUE, NO, http://tor.pw.is/, , , , 
http://tor.pw.is/dist/, , , , Wed Jan  8 16:41:17 2014
 t...@stalkr.net, stalkr.net, FR, France, FR, TRUE, TRUE, NO, 
http://tor.stalkr.net/, https://tor.stalkr.net/, , , 
http://tor.stalkr.net/dist/, https://tor.stalkr.net/dist/, , , Wed Jan  8 
16:41:17 2014
+m...@maki-chan.de,Maki 
Hoshisawa,DE,Germany,DE,TRUE,FALSE,NO,http://tor.mirrors.maki-chan.de/http://tor.mirrors.maki-chan.de/dist/
+doemela[AT]cyberguerrilla[DOT]org,cYbergueRrilLa AnonyMous 
NeXus,DE,Germany,DE,TRUE,FALSE,NO,https://tor-mirror.cyberguerrilla.orghttps://tor-mirror.cyberguerrilla.org/dist/,,,http://6dvj6v5imhny3anf.onion,

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Add empty setup.cfg to make debuild happy.

2014-01-12 Thread art
commit 0ba21296c5c2a570ec3e0028bf2c58bc187593aa
Author: Arturo Filastò 
Date:   Sat Jan 11 18:02:36 2014 +0100

Add empty setup.cfg to make debuild happy.
---
 0 files changed

diff --git a/setup.cfg b/setup.cfg
new file mode 100644
index 000..e69de29



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Merge branch 'master' of github.com:TheTorProject/ooni-probe

2014-01-12 Thread art
commit ad58966a76131e6fcb0a0c9e97c82249bb45bf5c
Merge: 9e3261d 98d969b
Author: Arturo Filastò 
Date:   Sat Jan 11 17:51:32 2014 +0100

Merge branch 'master' of github.com:TheTorProject/ooni-probe

* 'master' of github.com:TheTorProject/ooni-probe:
  Add logo to README.

 README.md |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Add logo to README.

2014-01-12 Thread art
commit 98d969b77c18505472b9d1273b30c8c7a35936e6
Author: Arturo Filastò 
Date:   Sat Jan 11 17:27:55 2014 +0100

Add logo to README.
---
 README.md |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/README.md b/README.md
index 6f09ca1..deb1b6f 100644
--- a/README.md
+++ b/README.md
@@ -1,7 +1,7 @@
 [![Build 
Status](https://travis-ci.org/TheTorProject/ooni-probe.png?branch=master)](https://travis-ci.org/TheTorProject/ooni-probe)
 [![Coverage 
Status](https://coveralls.io/repos/TheTorProject/ooni-probe/badge.png)](https://coveralls.io/r/TheTorProject/ooni-probe)
 
-# ooniprobe - Open Observatory of Network Interference
+![OONI](https://ooni.torproject.org/theme/img/ooni-logo.png)
 
 "The Net interprets censorship as damage and routes around it."
 - John Gilmore; TIME magazine (6 December 1993)



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Add script for harvesting collector and test helper addresses

2014-01-12 Thread art
commit dd591db19187fe2684e13ccb92fd6bd0435c08b0
Author: Arturo Filastò 
Date:   Fri Jan 10 18:58:56 2014 +0100

Add script for harvesting collector and test helper addresses
---
 fabfile.py |   47 ++-
 1 file changed, 46 insertions(+), 1 deletion(-)

diff --git a/fabfile.py b/fabfile.py
index 119d669..f97f6df 100644
--- a/fabfile.py
+++ b/fabfile.py
@@ -4,9 +4,12 @@
 # :license: see included LICENSE file
 import os
 import sys
+import yaml
 import xmlrpclib
+from StringIO import StringIO
 
-from fabric.api import run, cd, sudo
+from fabric.operations import get
+from fabric.api import run, cd, sudo, env
 
 api_auth = {}
 # Set these values 
@@ -17,6 +20,12 @@ slice_name = "your_slice_name"
 ### Do not change this
 api_auth['AuthMethod'] = "password"
 
+env.user = 'root'
+def set_hosts(host_file):
+with open(host_file) as f:
+for host in f:
+env.hosts.append(host)
+
 def search_node(nfilter="*.cert.org.cn"):
 api_server = xmlrpclib.ServerProxy('https://www.planet-lab.org/PLCAPI/')
 if api_server.AuthCheck(api_auth):
@@ -53,3 +62,39 @@ def deployooniprobe(distro="debian"):
 run("pip install https://hg.secdev.org/scapy/archive/tip.zip";)
 run("pip install -r requirements.txt")
 
+def generate_bouncer_file(install_directory='/data/oonib/', 
bouncer_file="bouncer.yaml"):
+output = StringIO()
+get(os.path.join(install_directory, 'oonib.conf'), output)
+output.seek(0)
+oonib_configuration = yaml.safe_load(output)
+
+output.truncate(0)
+get(os.path.join(oonib_configuration['main']['tor_datadir'], 'collector', 
'hostname'),
+output)
+output.seek(0)
+collector_hidden_service = output.readlines()[0].strip()
+
+address = env.host
+test_helpers = {
+'dns': address + ':' + 
str(oonib_configuration['helpers']['dns']['tcp_port']),
+'ssl': 'https://' + address,
+'traceroute': address,
+}
+if oonib_configuration['helpers']['tcp-echo']['port'] == 80:
+test_helpers['tcp-echo'] = address
+else:
+test_helpers['http-return-json-headers'] = 'http://' + address
+
+bouncer_data = {
+'collector': 
+{
+'httpo://'+collector_hidden_service: {'test-helper': 
test_helpers}
+}
+}
+with open(bouncer_file) as f:
+old_bouncer_data = yaml.safe_load(f)
+
+with open(bouncer_file, 'w+') as f:
+old_bouncer_data['collector']['httpo://'+collector_hidden_service] = {}
+
old_bouncer_data['collector']['httpo://'+collector_hidden_service]['test-helper']
 = test_helpers
+yaml.dump(old_bouncer_data, f)



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Do not include the city data by default.

2014-01-12 Thread art
commit d5ad65bbc4b4ca1adfa296d435179a754aa220fe
Author: Arturo Filastò 
Date:   Fri Jan 10 17:17:58 2014 +0100

Do not include the city data by default.

Closes #228
---
 data/ooniprobe.conf.sample |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/data/ooniprobe.conf.sample b/data/ooniprobe.conf.sample
index 412923a..6fa7caf 100644
--- a/data/ooniprobe.conf.sample
+++ b/data/ooniprobe.conf.sample
@@ -13,7 +13,7 @@ privacy:
 # Should we include the country as reported by GeoIP in the report?
 includecountry: true
 # Should we include the city as reported by GeoIP in the report?
-includecity: true
+includecity: false
 # Should we collect a full packet capture on the client?
 includepcap: false
 reports:



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Implement workaround to allow importing libdnet on debian

2014-01-12 Thread art
commit 4898ecb109180cb5596b0a1103ca3513b8ac98ae
Author: Arturo Filastò 
Date:   Sun Jan 12 15:40:48 2014 +0100

Implement workaround to allow importing libdnet on debian
---
 ooni/utils/txscapy.py |6 ++
 1 file changed, 6 insertions(+)

diff --git a/ooni/utils/txscapy.py b/ooni/utils/txscapy.py
index ae33365..876555b 100644
--- a/ooni/utils/txscapy.py
+++ b/ooni/utils/txscapy.py
@@ -31,6 +31,12 @@ def pcapdnet_installed():
 False
 if one of the two is absent
 """
+# In debian libdnet is called dumbnet instead of dnet, but scapy is
+# expecting "dnet" so we try and import it under such name.
+try:
+import dumbnet as dnet
+except ImportError: pass
+
 try:
 conf.use_pcap = True
 conf.use_dnet = True



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Properly format the copyright file.

2014-01-12 Thread art
commit 0c4f767826528b49e2ee090061d4031f1c500b3d
Author: Arturo Filastò 
Date:   Sat Jan 11 18:11:40 2014 +0100

Properly format the copyright file.
---
 debian/copyright |9 ++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/debian/copyright b/debian/copyright
index 1b60570..cbe2380 100644
--- a/debian/copyright
+++ b/debian/copyright
@@ -23,6 +23,12 @@ License: permissive
  provided the copyright notice and this notice are
  preserved.
 
+Files: data/Geo*.dat
+Copyright: 2013 MaxMind
+License: CC BY-SA
+ This product includes GeoLite data created by MaxMind, available from
+ http://www.maxmind.com";>http://www.maxmind.com.
+
 License: BSD-2-clause
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
@@ -43,6 +49,3 @@ License: BSD-2-clause
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-This product includes GeoLite data created by MaxMind, available from
-http://www.maxmind.com";>http://www.maxmind.com.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Add logo to README.

2014-01-12 Thread art
commit adc4113bfb4b131f8dbbb48a8101499a7f184d36
Author: Arturo Filastò 
Date:   Sat Jan 11 17:27:55 2014 +0100

Add logo to README.
---
 README.md |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/README.md b/README.md
index 6f09ca1..deb1b6f 100644
--- a/README.md
+++ b/README.md
@@ -1,7 +1,7 @@
 [![Build 
Status](https://travis-ci.org/TheTorProject/ooni-probe.png?branch=master)](https://travis-ci.org/TheTorProject/ooni-probe)
 [![Coverage 
Status](https://coveralls.io/repos/TheTorProject/ooni-probe/badge.png)](https://coveralls.io/r/TheTorProject/ooni-probe)
 
-# ooniprobe - Open Observatory of Network Interference
+![OONI](https://ooni.torproject.org/theme/img/ooni-logo.png)
 
 "The Net interprets censorship as damage and routes around it."
 - John Gilmore; TIME magazine (6 December 1993)



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Add empty setup.cfg to make debuild happy.

2014-01-12 Thread art
commit 8b87427e6267c046e8cd7692b1781b381e16c4ee
Author: Arturo Filastò 
Date:   Sat Jan 11 18:02:36 2014 +0100

Add empty setup.cfg to make debuild happy.
---
 0 files changed

diff --git a/setup.cfg b/setup.cfg
new file mode 100644
index 000..e69de29



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Properly format the copyright file.

2014-01-12 Thread art
commit 7d3c4196b2490e9d6a19893fadb65e5bbbad8198
Author: Arturo Filastò 
Date:   Sat Jan 11 18:11:40 2014 +0100

Properly format the copyright file.
---
 debian/copyright |9 ++---
 1 file changed, 6 insertions(+), 3 deletions(-)

diff --git a/debian/copyright b/debian/copyright
index 1b60570..cbe2380 100644
--- a/debian/copyright
+++ b/debian/copyright
@@ -23,6 +23,12 @@ License: permissive
  provided the copyright notice and this notice are
  preserved.
 
+Files: data/Geo*.dat
+Copyright: 2013 MaxMind
+License: CC BY-SA
+ This product includes GeoLite data created by MaxMind, available from
+ http://www.maxmind.com";>http://www.maxmind.com.
+
 License: BSD-2-clause
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
@@ -43,6 +49,3 @@ License: BSD-2-clause
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-This product includes GeoLite data created by MaxMind, available from
-http://www.maxmind.com";>http://www.maxmind.com.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Replace the name in the changelog with "Open Observatory of Network Interference"

2014-01-12 Thread art
commit 1937d56eff8c0d1e12dfd11e6943fa3008f34642
Author: Arturo Filastò 
Date:   Sun Jan 12 15:41:15 2014 +0100

Replace the name in the changelog with "Open Observatory of Network 
Interference"
---
 debian/changelog |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/debian/changelog b/debian/changelog
index 416aee4..05b6f6d 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -2,4 +2,4 @@ ooniprobe (1.0.0-rc5-1) UNRELEASED; urgency=low
 
   * Initial release. (Closes: #XX)
 
- -- Jérémy Bobbio   Fri, 3 Jan 2014 11:14:46 +0200
+ -- Open Observatory of Network Interference  Fri, 3 
Jan 2014 11:14:46 +0200



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Merge branch 'master' of github.com:TheTorProject/ooni-probe

2014-01-12 Thread art
commit e24a36b3faf4bd3f80ddc7f86042b6ccfb6479a0
Merge: 1937d56 0c4f767
Author: Arturo Filastò 
Date:   Sun Jan 12 15:43:18 2014 +0100

Merge branch 'master' of github.com:TheTorProject/ooni-probe

* 'master' of github.com:TheTorProject/ooni-probe:
  Properly format the copyright file.
  Add empty setup.cfg to make debuild happy.
  Add logo to README.

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Add line about the MaxMind GeoIP database to LICENSE

2014-01-12 Thread art
commit 5272883262d9e13b479ecbef5bb1c134823805c1
Author: Arturo Filastò 
Date:   Sat Jan 11 17:41:09 2014 +0100

Add line about the MaxMind GeoIP database to LICENSE
---
 LICENSE |3 +++
 1 file changed, 3 insertions(+)

diff --git a/LICENSE b/LICENSE
index 86cf173..43eb027 100644
--- a/LICENSE
+++ b/LICENSE
@@ -24,3 +24,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 The views and conclusions contained in the software and documentation are those
 of the authors and should not be interpreted as representing official policies,
 either expressed or implied, of the FreeBSD Project.
+
+This product includes GeoLite data created by MaxMind, available from
+http://www.maxmind.com";>http://www.maxmind.com.



___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [ooni-probe/master] Add debian directory based on: http://anonscm.debian.org/gitweb/?p=collab-maint/ooni-probe.git

2014-01-12 Thread art
commit 9e3261d1232122aaf1f373c759e31953f9111993
Author: Arturo Filastò 
Date:   Sat Jan 11 17:50:39 2014 +0100

Add debian directory based on: 
http://anonscm.debian.org/gitweb/?p=collab-maint/ooni-probe.git
---
 debian/README|5 +
 debian/changelog |5 +
 debian/compat|1 +
 debian/control   |   40 
 debian/copyright |   48 
 debian/rules |4 
 debian/source/format |1 +
 7 files changed, 104 insertions(+)

diff --git a/debian/README b/debian/README
new file mode 100644
index 000..a816b35
--- /dev/null
+++ b/debian/README
@@ -0,0 +1,5 @@
+Debian package for ooni-probe
+=
+
+The Debian package is currently missing the graphical user interface as it
+needs several JavaScript libraries that are currently not available in Debian.
diff --git a/debian/changelog b/debian/changelog
new file mode 100644
index 000..416aee4
--- /dev/null
+++ b/debian/changelog
@@ -0,0 +1,5 @@
+ooniprobe (1.0.0-rc5-1) UNRELEASED; urgency=low
+
+  * Initial release. (Closes: #XX)
+
+ -- Jérémy Bobbio   Fri, 3 Jan 2014 11:14:46 +0200
diff --git a/debian/compat b/debian/compat
new file mode 100644
index 000..45a4fb7
--- /dev/null
+++ b/debian/compat
@@ -0,0 +1 @@
+8
diff --git a/debian/control b/debian/control
new file mode 100644
index 000..60f42cb
--- /dev/null
+++ b/debian/control
@@ -0,0 +1,40 @@
+Source: ooniprobe
+Maintainer: Open Observatory of Network Interference 
+Section: net
+Priority: extra
+Build-Depends: debhelper (>= 8),
+   python-all (>= 2.6.6-3~),
+   python-dnspython (>= 1.10.0),
+   python-docutils (>= 0.9.1),
+   python-geoip (>= 0.2.5),
+   python-ipaddr (>= 2.1.10),
+   python-openssl (>= 0.13),
+   python-pyrex,
+   python-scapy (>= 2.2),
+   python-setuptools,
+   python-twisted (>= 12.2.0),
+   python-txsocksx,
+   python-txtorcon (>= 0.7),
+   python-yaml (>= 3.10),
+   python-zope.interface (>= 3.6),
+Standards-Version: 3.9.4
+X-Python-Version: >= 2.7
+Vcs-Git: git://anonscm.debian.org/git/collab-maint/ooni-probe.git
+Vcs-Browser: http://anonscm.debian.org/gitweb/?p=collab-maint/ooni-probe.git
+Homepage: https://ooni.torproject.org/
+
+Package: ooniprobe
+Architecture: all
+Depends: ${misc:Depends}, ${python:Depends},
+   tcpdump,
+   tor
+Suggests: obfsproxy
+Description: probe for the Open Observatory of Network Interference (OONI)
+ OONI, the Open Observatory of Network Interference, is a global observation
+ network which aims is to collect high quality data using open methodologies
+ and free software to share observations and data about the various types,
+ methods, and amounts of network tampering in the world.
+ .
+ ooniprobe is a program to probe a network and collect data for the OONI
+ project. It will test the current network for signs of surveillance and
+ censorship.
diff --git a/debian/copyright b/debian/copyright
new file mode 100644
index 000..1b60570
--- /dev/null
+++ b/debian/copyright
@@ -0,0 +1,48 @@
+Format: http://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+Upstream-Name: ooniprobe
+Source: https://gitweb.torproject.org/ooni-probe.git
+
+Files: *
+Copyright: 2012-2013 Jacob Appelbaum, Arturo Filastò, Isis Lovecruft,
+ Aaron Gibson
+License: BSD-2-clause
+
+Files: data/nettests/experimental/tls_handshake.py
+Copyright: 2013 Isis Lovecruft, The Tor Project Inc.
+License: BSD-2-clause
+
+Files: ooni/utils/onion.py
+Copyright: 2012 The Tor Project, Inc.
+License: BSD-2-clause
+
+Files: debian/*
+Copyright: 2013 Jerémy Bobbio 
+License: permissive
+ Copying and distribution of this package, with or without
+ modification, are permitted in any medium without royalty
+ provided the copyright notice and this notice are
+ preserved.
+
+License: BSD-2-clause
+ Redistribution and use in source and binary forms, with or without
+ modification, are permitted provided that the following conditions
+ are met:
+ 1. Redistributions of source code must retain the above copyright
+notice, this list of conditions and the following disclaimer.
+ 2. Redistributions in binary form must reproduce the above copyright
+notice, this list of conditions and the following disclaimer in the
+documentation and/or other materials provided with the distribution.
+ .
+ THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
+ NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR S

[tor-commits] [translation/tails-misc_completed] Update translations for tails-misc_completed

2014-01-12 Thread translation
commit 15fe67812650c5f9ffada2f3970791911a7e9586
Author: Translation commit bot 
Date:   Sun Jan 12 12:16:19 2014 +

Update translations for tails-misc_completed
---
 sv.po |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/sv.po b/sv.po
index 8202c96..f2d7c4f 100644
--- a/sv.po
+++ b/sv.po
@@ -9,7 +9,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2014-01-10 12:23+0100\n"
-"PO-Revision-Date: 2014-01-11 13:40+\n"
+"PO-Revision-Date: 2014-01-12 12:09+\n"
 "Last-Translator: WinterFairy \n"
 "Language-Team: Swedish 
(http://www.transifex.com/projects/p/torproject/language/sv/)\n"
 "MIME-Version: 1.0\n"
@@ -291,7 +291,7 @@ msgstr "Startar I2P..."
 
 #: config/chroot_local-includes/usr/local/bin/tails-start-i2p:63
 msgid "The I2P router console will be opened on start."
-msgstr "I2Ps routerkonsoll kommer att öppnas vid start."
+msgstr "I2Ps routerkonsol kommer att öppnas vid start."
 
 #: config/chroot_local-includes/usr/local/bin/tails-start-i2p:82
 #: config/chroot_local-includes/usr/local/bin/tails-start-i2p:124

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/tails-misc] Update translations for tails-misc

2014-01-12 Thread translation
commit 7a5a554968ffe0f028aa3ccef34cf584640da173
Author: Translation commit bot 
Date:   Sun Jan 12 12:16:14 2014 +

Update translations for tails-misc
---
 sv.po |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/sv.po b/sv.po
index 8202c96..f2d7c4f 100644
--- a/sv.po
+++ b/sv.po
@@ -9,7 +9,7 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2014-01-10 12:23+0100\n"
-"PO-Revision-Date: 2014-01-11 13:40+\n"
+"PO-Revision-Date: 2014-01-12 12:09+\n"
 "Last-Translator: WinterFairy \n"
 "Language-Team: Swedish 
(http://www.transifex.com/projects/p/torproject/language/sv/)\n"
 "MIME-Version: 1.0\n"
@@ -291,7 +291,7 @@ msgstr "Startar I2P..."
 
 #: config/chroot_local-includes/usr/local/bin/tails-start-i2p:63
 msgid "The I2P router console will be opened on start."
-msgstr "I2Ps routerkonsoll kommer att öppnas vid start."
+msgstr "I2Ps routerkonsol kommer att öppnas vid start."
 
 #: config/chroot_local-includes/usr/local/bin/tails-start-i2p:82
 #: config/chroot_local-includes/usr/local/bin/tails-start-i2p:124

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [doctor/java] Don't display total number of relays in consensus.

2014-01-12 Thread karsten
commit 4c97819ac5c757da52fb19b7d1440060445410ff
Author: Karsten Loesing 
Date:   Sun Jan 12 11:23:58 2014 +0100

Don't display total number of relays in consensus.

ln5 says this number is misleading, because there are only Running relays
in the consensus.
---
 src/org/torproject/doctor/MetricsWebsiteReport.java |4 +---
 1 file changed, 1 insertion(+), 3 deletions(-)

diff --git a/src/org/torproject/doctor/MetricsWebsiteReport.java 
b/src/org/torproject/doctor/MetricsWebsiteReport.java
index 019f71d..e72b5fd 100644
--- a/src/org/torproject/doctor/MetricsWebsiteReport.java
+++ b/src/org/torproject/doctor/MetricsWebsiteReport.java
@@ -230,9 +230,7 @@ public class MetricsWebsiteReport {
 this.bw.write("  \n"
 + "consensus"
   + "\n"
-+ ""
-  + this.downloadedConsensus.getStatusEntries().size()
-  + " total\n"
++ "\n"
 + "" + runningRelays
   + " Running\n"
 + "  \n"

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/liveusb-creator] Update translations for liveusb-creator

2014-01-12 Thread translation
commit b2e0b6fa4f9d084639427375178618f1c2e50c47
Author: Translation commit bot 
Date:   Sun Jan 12 09:45:57 2014 +

Update translations for liveusb-creator
---
 ru/ru.po |8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/ru/ru.po b/ru/ru.po
index 0d0b6df..793313e 100644
--- a/ru/ru.po
+++ b/ru/ru.po
@@ -8,7 +8,7 @@
 # varnav, 2013
 # ddark008 , 2012
 # Арефьев Денис , 2013
-# oulgocke , 2013
+# oulgocke , 2013-2014
 # tavarysh , 2013
 # vlasok , 2012
 # Yulia , 2009
@@ -17,8 +17,8 @@ msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
 "POT-Creation-Date: 2014-01-10 11:27+0100\n"
-"PO-Revision-Date: 2014-01-11 09:25+\n"
-"Last-Translator: runasand \n"
+"PO-Revision-Date: 2014-01-12 09:25+\n"
+"Last-Translator: oulgocke \n"
 "Language-Team: Russian 
(http://www.transifex.com/projects/p/torproject/language/ru/)\n"
 "MIME-Version: 1.0\n"
 "Content-Type: text/plain; charset=UTF-8\n"
@@ -29,7 +29,7 @@ msgstr ""
 #: ../liveusb/dialog.py:159 ../liveusb/launcher_ui.py:158
 #, python-format
 msgid "%(distribution)s Installer"
-msgstr ""
+msgstr "Установщик %(distribution)s"
 
 #: ../liveusb/gui.py:808
 #, python-format

___
tor-commits mailing list
tor-commits@lists.torproject.org
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits


[tor-commits] [translation/liveusb-creator_completed] Update translations for liveusb-creator_completed

2014-01-12 Thread translation
commit 8c8c7183edfb029e3bae99b88565d86c400e7d81
Author: Translation commit bot 
Date:   Sun Jan 12 09:46:02 2014 +

Update translations for liveusb-creator_completed
---
 ru/ru.po |  130 +++---
 1 file changed, 65 insertions(+), 65 deletions(-)

diff --git a/ru/ru.po b/ru/ru.po
index 3d3743f..793313e 100644
--- a/ru/ru.po
+++ b/ru/ru.po
@@ -8,7 +8,7 @@
 # varnav, 2013
 # ddark008 , 2012
 # Арефьев Денис , 2013
-# oulgocke , 2013
+# oulgocke , 2013-2014
 # tavarysh , 2013
 # vlasok , 2012
 # Yulia , 2009
@@ -16,8 +16,8 @@ msgid ""
 msgstr ""
 "Project-Id-Version: The Tor Project\n"
 "Report-Msgid-Bugs-To: \n"
-"POT-Creation-Date: 2013-11-12 13:29+0100\n"
-"PO-Revision-Date: 2013-11-18 19:40+\n"
+"POT-Creation-Date: 2014-01-10 11:27+0100\n"
+"PO-Revision-Date: 2014-01-12 09:25+\n"
 "Last-Translator: oulgocke \n"
 "Language-Team: Russian 
(http://www.transifex.com/projects/p/torproject/language/ru/)\n"
 "MIME-Version: 1.0\n"
@@ -28,25 +28,25 @@ msgstr ""
 
 #: ../liveusb/dialog.py:159 ../liveusb/launcher_ui.py:158
 #, python-format
-msgid "%(distribution)s installer"
+msgid "%(distribution)s Installer"
 msgstr "Установщик %(distribution)s"
 
-#: ../liveusb/gui.py:807
+#: ../liveusb/gui.py:808
 #, python-format
 msgid "%(filename)s selected"
 msgstr "%(filename)s выбрано"
 
-#: ../liveusb/gui.py:437
+#: ../liveusb/gui.py:439
 #, python-format
 msgid "%(size)s %(label)s"
 msgstr "%(size)s %(label)s"
 
-#: ../liveusb/gui.py:443
+#: ../liveusb/gui.py:445
 #, python-format
 msgid "%(vendor)s %(model)s (%(details)s) - %(device)s"
 msgstr "%(vendor)s %(model)s (%(details)s) - %(device)s"
 
-#: ../liveusb/creator.py:1023
+#: ../liveusb/creator.py:1020
 #, python-format
 msgid "%s already bootable"
 msgstr "%s уже загрузочный"
@@ -103,16 +103,16 @@ msgid ""
 "persist after a reboot."
 msgstr "Путём выделения дополнительного 
места на флешке для постоянного хранилища, 
Вы получите возможность сохранять данные и 
делать постоянные модификации Вашей живой 
ОС. Без этого у Вас не получится сохранить 
данные так, чтобы они остались после 
перезагрузки."
 
-#: ../liveusb/creator.py:1125 ../liveusb/creator.py:1388
+#: ../liveusb/creator.py:1122 ../liveusb/creator.py:1385
 #, python-format
 msgid "Calculating the SHA1 of %s"
 msgstr "Вычисление SHA1 от %s"
 
-#: ../liveusb/creator.py:1336
+#: ../liveusb/creator.py:1333
 msgid "Cannot find"
 msgstr "Невозможно найти"
 
-#: ../liveusb/creator.py:545
+#: ../liveusb/creator.py:542
 #, python-format
 msgid "Cannot find device %s"
 msgstr "Устройство %s не найдено"
@@ -136,7 +136,7 @@ msgstr "Клонировать\n&&\nОбновить"
 msgid "Creating %sMB persistent overlay"
 msgstr "Создание %sМБ постоянного хранилища"
 
-#: ../liveusb/gui.py:565
+#: ../liveusb/gui.py:567
 msgid ""
 "Device is not yet mounted, so we cannot determine the amount of free space."
 msgstr "Устройство пока не примонтировано, 
поэтому нельзя определить количество 
свободного места."
@@ -146,11 +146,11 @@ msgstr "Устройство пока не 
примонтировано, поэ
 msgid "Download %(distribution)s"
 msgstr "Загрузка %(distribution)s"
 
-#: ../liveusb/gui.py:781
+#: ../liveusb/gui.py:782
 msgid "Download complete!"
 msgstr "Загрузка завершена!"
 
-#: ../liveusb/gui.py:785
+#: ../liveusb/gui.py:786
 msgid "Download failed: "
 msgstr "Ошибка загрузки: "
 
@@ -159,16 +159,16 @@ msgstr "Ошибка загрузки: "
 msgid "Downloading %s..."
 msgstr "Загрузка %s..."
 
-#: ../liveusb/creator.py:1121
+#: ../liveusb/creator.py:1118
 msgid "Drive is a loopback, skipping MBR reset"
 msgstr "Этот диск является петлевым 
устройством, пропускаем сброс MBR"
 
-#: ../liveusb/creator.py:816
+#: ../liveusb/creator.py:813
 #, python-format
 msgid "Entering unmount_device for '%(device)s'"
 msgstr "Открытие непримонтированного 
устройства для  '%(device)s'"
 
-#: ../liveusb/creator.py:1201
+#: ../liveusb/creator.py:1198
 msgid "Error probing device"
 msgstr "Ошибка зондирования устройства"
 
@@ -188,7 +188,7 @@ msgstr "Ошибка: Неверное SHA1 вашего 
Live CD образа.
 msgid "Extracting live image to the target device..."
 msgstr "Извлечение живого образа на целевое 
устройство..."
 
-#: ../liveusb/creator.py:1066
+#: ../liveusb/creator.py:1063
 #, python-format
 msgid "Formatting %(device)s as FA

[tor-commits] [translation/tsum] Update translations for tsum

2014-01-12 Thread translation
commit 4bc2d911a3b06a1987534d7ae5f6174b1ca5529d
Author: Translation commit bot 
Date:   Sun Jan 12 08:15:09 2014 +

Update translations for tsum
---
 he/short-user-manual_he_noimg.xhtml |6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/he/short-user-manual_he_noimg.xhtml 
b/he/short-user-manual_he_noimg.xhtml
index f91b1e0..01defb2 100644
--- a/he/short-user-manual_he_noimg.xhtml
+++ b/he/short-user-manual_he_noimg.xhtml
@@ -13,13 +13,13 @@
 Tor יהפוך את המקור של התעבורה שלכם לאנונ
ימי, וכן יצפין כל דבר בינכם לבין הרשת Tor. Tor 
גם יצפין את התעבורה שלכם בתוך הרשת Tor, אך אין 
לו את היכולת להצפין את התעבורה שלכם בין 
הרשת Tor לבין היעד הסופי.
 במידה ואתם מעבירים מידע רגיש, למשל כאשר 
אתם נכנסים אל אתר רשת עם שם משתמש וסיסמה, 
ודאו היטב כי אתם מפיקים שימוש מן HTTPS (דוגמא 
https://torproject.org/, ולא 
http://torproject.org/).
 כיצד להוריד את Tor
-האגודה אותה אנו ממליצים לרוב המשתמשים 
היא https://www.torproject.org/projects/torbrowser.html";>חבילת 
הדפדפן של Tor. אגודה זו מכילה דפדפן מוגדר 
מראש לדפדוף בבטיחות באינטרנט מבעד אל Tor, וזו 
לא מצריכה התקנה. אתם מוריד את האגודה, מחלצים 
את הארכיון, ומתחילים את Tor.
+החבילה אנו ממליצים לרוב המשתמשים היא https://www.torproject.org/projects/torbrowser.html";>חבילת 
הדפדפן של Tor. חבילה זו מכילה דפדפן מוגדר 
מראש לדפדוף בבטיחות באינטרנט דרך Tor, ולא 
צורך התקנה. אתם מורידים את החבילה, פורסים את 
הארכיון, ומריצים את Tor.
 קיימות שתי דרכים שונות להשגת התוכנה Tor. 
באפשרותכם לדפדף בתוך https://www.torproject.org/";>אתר הרשת של הפרויקט Tor 
ולהוריד אותה שם, לחלופין באפשרותך להשתמש 
בתוכנית GetTor, משיב דוא״ל אוטומטי.
 כיצד להשיג את Tor דרך 
דוא״ל
 כדי לקבל את חבילת הדפדפן של Tor בשפה האנ
גלית עבור Windows, שלחו דוא״ל אל get...@torproject.org עם 
windows בתוך גוף ההודעה. באפשרותכם 
להותיר את הנושא ריק.
 באפשרותכם גם לבקש את חבילת הדפדפן של Tor 
עבור Mac OS X (רשום macos-i386), וגם Linux 
(רשום linux-i386 עבור מערכות 32-bit או 
linux-x86_64 עבור מערכות 64-bit).
 אם רצונכם בגרסא מתורגמת של Tor, רשום 
help במקום. אתם תקבלו דוא״ל עם 
הוראות ורשימה של שפות זמינות.
-הערה: חבילות הדפדפן של Tor עבור 
Linux ועבור Mac OS X גדולים למדי, ואתם לא תהיו 
מסוגלים לקבל איזו מן אגודות אלה עם חשבון 
Gmail, Hotmail או Yahoo. במידה ואתם לא יכולים לקבל את 
האגודה אותה ברצונכם לקבל, שלחו דוא״ל אל 
h...@rt.torproject.org ואנחנו נמסור לכם רשימת מראות 
(mirror) של אתר רשת למטרה זו.
+הערה: חבילות הדפדפן של Tor עבור 
Linux ועבור Mac OS X גדולים למדי, ולא תהיו מסוגלים 
להשיג אף לא אחת מחבילות אלה עם חשבון Gmail, 
Hotmail או Yahoo. במידה ואתם לא יכולים לקבל את 
החבילה אותה ברצונכם לקבל, שלחו דוא״ל אל 
h...@rt.torproject.org ואנחנו נמסור לכם רשימת מראות 
(mirrors) של אתר רשת למטרה זו.
 Tor עבור טלפונים חכמים
 באפשרותכם להשיג Tor במכשיר Android על ידי 
התקנת חבילה בשם Orbot. למידע אודות כיצד 
להוריד ולהתקין את Orbot, אנא עיינו בתוך https://www.torproject.org/docs/android.html.en";>אתר פרויקט 
Tor.
 יש לנו גם חבילות ניסיוניות עבור https://www.torproject.org/docs/N900.html.en";>Nokia Maemo/N900 וגם 
עבור http://sid77.slackware.it/iphone/";>Apple iOS.
@@ -122,7 +122,7 @@ sub   2048R/EB399FD7 2003-10-16
 Flash לא פועל
 מטעמים של אבטחה, Flash, Java, ותוספות אחרות 
מנוטרלות נכון להיום למען Tor. תוספות מופעלות 
באופן עצמאי מן Firefox ומסוגלות לנהל פעילות על 
מחשבכם דבר אשר פוגע בפרטיות שלכם.
 סרטוני YouTube לרוב עובדים עם HTML5, וזה 
אפשרי לצפות בסרטונים אלו

[tor-commits] [translation/tsum_completed] Update translations for tsum_completed

2014-01-12 Thread translation
commit 9d21fb293e10ad40c1eb1e22765e51a61f1a7d3d
Author: Translation commit bot 
Date:   Sun Jan 12 08:15:12 2014 +

Update translations for tsum_completed
---
 he/short-user-manual_he_noimg.xhtml |6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/he/short-user-manual_he_noimg.xhtml 
b/he/short-user-manual_he_noimg.xhtml
index f91b1e0..01defb2 100644
--- a/he/short-user-manual_he_noimg.xhtml
+++ b/he/short-user-manual_he_noimg.xhtml
@@ -13,13 +13,13 @@
 Tor יהפוך את המקור של התעבורה שלכם לאנונ
ימי, וכן יצפין כל דבר בינכם לבין הרשת Tor. Tor 
גם יצפין את התעבורה שלכם בתוך הרשת Tor, אך אין 
לו את היכולת להצפין את התעבורה שלכם בין 
הרשת Tor לבין היעד הסופי.
 במידה ואתם מעבירים מידע רגיש, למשל כאשר 
אתם נכנסים אל אתר רשת עם שם משתמש וסיסמה, 
ודאו היטב כי אתם מפיקים שימוש מן HTTPS (דוגמא 
https://torproject.org/, ולא 
http://torproject.org/).
 כיצד להוריד את Tor
-האגודה אותה אנו ממליצים לרוב המשתמשים 
היא https://www.torproject.org/projects/torbrowser.html";>חבילת 
הדפדפן של Tor. אגודה זו מכילה דפדפן מוגדר 
מראש לדפדוף בבטיחות באינטרנט מבעד אל Tor, וזו 
לא מצריכה התקנה. אתם מוריד את האגודה, מחלצים 
את הארכיון, ומתחילים את Tor.
+החבילה אנו ממליצים לרוב המשתמשים היא https://www.torproject.org/projects/torbrowser.html";>חבילת 
הדפדפן של Tor. חבילה זו מכילה דפדפן מוגדר 
מראש לדפדוף בבטיחות באינטרנט דרך Tor, ולא 
צורך התקנה. אתם מורידים את החבילה, פורסים את 
הארכיון, ומריצים את Tor.
 קיימות שתי דרכים שונות להשגת התוכנה Tor. 
באפשרותכם לדפדף בתוך https://www.torproject.org/";>אתר הרשת של הפרויקט Tor 
ולהוריד אותה שם, לחלופין באפשרותך להשתמש 
בתוכנית GetTor, משיב דוא״ל אוטומטי.
 כיצד להשיג את Tor דרך 
דוא״ל
 כדי לקבל את חבילת הדפדפן של Tor בשפה האנ
גלית עבור Windows, שלחו דוא״ל אל get...@torproject.org עם 
windows בתוך גוף ההודעה. באפשרותכם 
להותיר את הנושא ריק.
 באפשרותכם גם לבקש את חבילת הדפדפן של Tor 
עבור Mac OS X (רשום macos-i386), וגם Linux 
(רשום linux-i386 עבור מערכות 32-bit או 
linux-x86_64 עבור מערכות 64-bit).
 אם רצונכם בגרסא מתורגמת של Tor, רשום 
help במקום. אתם תקבלו דוא״ל עם 
הוראות ורשימה של שפות זמינות.
-הערה: חבילות הדפדפן של Tor עבור 
Linux ועבור Mac OS X גדולים למדי, ואתם לא תהיו 
מסוגלים לקבל איזו מן אגודות אלה עם חשבון 
Gmail, Hotmail או Yahoo. במידה ואתם לא יכולים לקבל את 
האגודה אותה ברצונכם לקבל, שלחו דוא״ל אל 
h...@rt.torproject.org ואנחנו נמסור לכם רשימת מראות 
(mirror) של אתר רשת למטרה זו.
+הערה: חבילות הדפדפן של Tor עבור 
Linux ועבור Mac OS X גדולים למדי, ולא תהיו מסוגלים 
להשיג אף לא אחת מחבילות אלה עם חשבון Gmail, 
Hotmail או Yahoo. במידה ואתם לא יכולים לקבל את 
החבילה אותה ברצונכם לקבל, שלחו דוא״ל אל 
h...@rt.torproject.org ואנחנו נמסור לכם רשימת מראות 
(mirrors) של אתר רשת למטרה זו.
 Tor עבור טלפונים חכמים
 באפשרותכם להשיג Tor במכשיר Android על ידי 
התקנת חבילה בשם Orbot. למידע אודות כיצד 
להוריד ולהתקין את Orbot, אנא עיינו בתוך https://www.torproject.org/docs/android.html.en";>אתר פרויקט 
Tor.
 יש לנו גם חבילות ניסיוניות עבור https://www.torproject.org/docs/N900.html.en";>Nokia Maemo/N900 וגם 
עבור http://sid77.slackware.it/iphone/";>Apple iOS.
@@ -122,7 +122,7 @@ sub   2048R/EB399FD7 2003-10-16
 Flash לא פועל
 מטעמים של אבטחה, Flash, Java, ותוספות אחרות 
מנוטרלות נכון להיום למען Tor. תוספות מופעלות 
באופן עצמאי מן Firefox ומסוגלות לנהל פעילות על 
מחשבכם דבר אשר פוגע בפרטיות שלכם.
 סרטוני YouTube לרוב עובדים עם HTML5, וזה 
אפשרי לצפות בסרטונ×
diff --git a/pt.go b/pt.go
index c77687f..024eec9 100644
--- a/pt.go
+++ b/pt.go
@@ -315,24 +315,16 @@ func getManagedTransportVer() (string, error) {
 // Get the intersection of the method names offered by Tor and those in
 // methodNames. This function reads the environment variable
 // TOR_PT_CLIENT_TRANSPORTS.
-func getClientTransports(methodNames []string) ([]string, error) {
+func getClientTransports(star []string) ([]string, error) {
clientTransports, err := getenvRequired("TOR_PT_CLIENT_TRANSPORTS")
if err != nil {
return nil, err
}
if clientTransports == "*" {
-   return methodNames, nil
-   }
-   result := make([]string, 0)
-   for _, requested := range strings.Split(clientTransports, ",") {
-   for _, methodName := range methodNames {
-   if requested == methodName {
-   result = append(result, methodName)
-   break
-   }
-   }
+   return star, nil
+   } else {
+   return strings.Split(clientTransports, ","), nil
}
-   return result, nil
 }
 
 // This structure is returned by ClientSetup. It consists of a list of method
@@ -342,16 +334,17 @@ type ClientInfo struct {
 }
 
 // Check the client pluggable transports environment, emitting an error message
-// and returning a non-nil error if any error is encountered. Returns a
-// ClientInfo struct.
-func ClientSetup(methodNames []string) (info ClientInfo, err error) {
+// and returning a non-nil error if any error is encountered. star is the list
+// of method names to use in case "*" is requested by Tor. Resolves the various
+// Returns a ClientInfo struct.
+func ClientSetup(star []string) (info ClientInfo, err error) {
ver, err := getManagedTransportVer()
if err != nil {
return
}
line("VERSION", ver)
 
-   info.MethodNames, err = getClientTransports(methodNames)
+   info.MethodNames, err = getClientTransports(star)
if err != nil {
return
}
diff --git a/pt.go b/pt.go
index 391b1f5..c77687f 100644
--- a/pt.go
+++ b/pt.go
@@ -427,11 +427,12 @@ func filterBindaddrs(addrs []Bindaddr, methodNames 
[]string) []Bindaddr {
return result
 }
 
-// Return an array of Bindaddrs, those being the contents of
-// TOR_PT_SERVER_BINDADDR, with keys filtered by TOR_PT_SERVER_TRANSPORTS, and
-// further filtered by the methods in methodNames. Transport-specific options
-// from TOR_PT_SERVER_TRANSPORT_OPTIONS are assigned to the Options member.
-func getServerBindaddrs(methodNames []string) ([]Bindaddr, error) {
+// Return an array of Bindaddrs, being the contents of TOR_PT_SERVER_BINDADDR
+// with keys filtered by TOR_PT_SERVER_TRANSPORTS. If TOR_PT_SERVER_TRANSPORTS
+// is "*", then keys are filtered by the entries in star instead.
+// Transport-specific options from TOR_PT_SERVER_TRANSPORT_OPTIONS are assigned
+// to the Options member.
+func getServerBindaddrs(star []string) ([]Bindaddr, error) {
var result []Bindaddr
 
// Parse the list of server transport options.
@@ -468,13 +469,12 @@ func getServerBindaddrs(methodNames []string) 
([]Bindaddr, error) {
if err != nil {
return nil, err
}
-   if serverTransports != "*" {
+   if serverTransports == "*" {
+   result = filterBindaddrs(result, star)
+   } else {
result = filterBindaddrs(result, 
strings.Split(serverTransports, ","))
}
 
-   // Finally filter by what we understand.
-   result = filterBindaddrs(result, methodNames)
-
return result, nil
 }
 
@@ -525,17 +525,18 @@ type ServerInfo struct {
 }
 
 // Check the server pluggable transports environment, emitting an error message
-// and returning a non-nil error if any error is encountered. Resolves the
-// various requested bind addresses, the server ORPort and extended ORPort, and
-// reads the auth cookie file. Returns a ServerInfo struct.
-func ServerSetup(methodNames []string) (info ServerInfo, err error) {
+// and returning a non-nil error if any error is encountered. star is the list
+// of method names to use in case "*" is requested by Tor. Resolves the various
+// requested bind addresses, the server ORPort and extended ORPort, and reads
+// the auth cookie file. Returns a ServerInfo struct.
+func ServerSetup(star []string) (info ServerInfo, err error) {
ver, err := getManagedTransportVer()
if err != nil {
return
}
line("VERSION", ver)
 
-   info.Bindaddrs, err = getServerBindaddrs(methodNames)
+   info.Bindaddrs, err = getServerBindaddrs(star)
if err != nil {
return
}